-------------------------------------------------------------------------------
-- MrTrader 0.1
--
-- Lightweight addon to access profession information of alts.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

local Menu = LibStub("Dewdrop-2.0");
local L = LibStub("AceLocale-3.0"):GetLocale("MrTrader");

function MrTrader:InitializeMenu()
	local LDB = LibStub("LibDataBroker-1.1", true);
	if LDB then
		self.launcherobj = LDB:NewDataObject("MrTrader", {
	    	type = "launcher",
			label = "MrTrader",
	    	icon = "Interface\\Addons\\MrTrader\\MrTrader",
	    	OnClick = function(clickedframe, button)
	        	MrTrader:OpenMenu(clickedframe, button);
	    	end,
			OnTooltipShow = function(tip)
				if not tip or not tip.AddLine then return end
				tip:AddLine("MrTrader")
				tip:AddLine(L["Click to open menu."], 1, 1, 1)
			end,
		})
	end
end

function MrTrader:OpenMenu(frame, button)
	if button == "LeftButton" then
		Menu:Open(frame, "children", function() MrTrader:UpdateMenu() end);
	end
end

function MrTrader:UpdateMenu()
	MrTrader:QuerySkills();
	skillTable = MrTrader:GetSkillTable();
	currentPlayer = UnitName("player");
	
	local spacer = {
		text = "",
		isTitle = true,
	}
	
	menu = {};
	local index = 100;
	local characterCount = MrTrader:TableSize(skillTable);
	
	if skillTable[currentPlayer] then
		characterCount = characterCount - 1;
	
		menu[index] = {
			text = L["Tradeskills"],
			textR = 1.0,
			textG = 0.8,
			textB = 0,
			isTitle = true,
		}
		index = index + 1;
		
		for skillName, skillLink in pairs(skillTable[currentPlayer]) do
			menu[index] = {
				text = L[skillName],
				closeWhenClicked = true,
				func = function()
					MrTrader:OpenLink(skillName, skillLink, true);
				end,
			}
			index = index + 1;
		end
		
		menu[index] = spacer;
		index = index + 1;
	end
	
	if characterCount > 0 then
		menu[index] = {
			text = L["Characters"],
			textR = 1.0,
			textG = 0.8,
			textB = 0,
			isTitle = true,
		}
		index = index + 1;
	
		for playerName, skillList in pairs(skillTable) do
			if playerName ~= currentPlayer then
				menu[index] = {
					text = playerName,
					hasArrow = true,
				}
				menu[index].subMenu = {};
				local subMenuIndex = 100;
				
				for skillName, skillLink in pairs(skillTable[playerName]) do
					menu[index].subMenu[subMenuIndex] = {
						text = L[skillName],
						closeWhenClicked = true,
						disabled = not skillLink,
						func = function()
							MrTrader:OpenLink(skillName, skillLink, false);
						end,
					}
					subMenuIndex = subMenuIndex + 1;
				end
				
				index = index + 1;
			end
		end
		
		menu[index] = spacer;
		index = index + 1;
	end
	
	menu[index] = {
		text = L["Close"],
		closeWhenClicked = true,
	}
	
	Menu:FeedTable(menu);
end

function MrTrader:OpenLink(name, link, isCurrentPlayer)
	if IsModifiedClick() then
		-- Let the normal mechanisms handle the modified click on the link
		HandleModifiedItemClick(link);	
	else
		if isCurrentPlayer then
			CastSpellByName(L[name]);
		else
			-- Open link via chat window
			local chatLink = string.gsub(link, "|", ":");
			local _, startIndex = string.find(chatLink, ":H");
			local endIndex = string.find(chatLink, ":h");
			chatLink = string.sub(chatLink, startIndex + 1, endIndex - 1);
			ChatFrame_OnHyperlinkShow(nil, chatLink, link, "LeftButton");
		end
	end
end